/**
 * This file was auto-generated by Fern from our API Definition.
 */
import * as environments from "../../../../environments";
import * as core from "../../../../core";
import * as Flatfile from "../../../index";
export declare namespace DataClips {
    interface Options {
        environment?: core.Supplier<environments.FlatfileEnvironment | string>;
        /** Specify a custom URL to connect the client to. */
        baseUrl?: core.Supplier<string>;
        token?: core.Supplier<core.BearerToken | undefined>;
        /** Override the X-Disable-Hooks header */
        xDisableHooks?: "true";
        fetcher?: core.FetchFunction;
    }
    interface RequestOptions {
        /** The maximum time to wait for a response in seconds. */
        timeoutInSeconds?: number;
        /** The number of times to retry the request. Defaults to 2. */
        maxRetries?: number;
        /** A hook to abort the request. */
        abortSignal?: AbortSignal;
        /** Override the X-Disable-Hooks header */
        xDisableHooks?: "true";
        /** Additional headers to include in the request. */
        headers?: Record<string, string>;
    }
}
export declare class DataClips {
    protected readonly _options: DataClips.Options;
    constructor(_options?: DataClips.Options);
    /**
     * Creates a new DataClip.
     *
     * @param {Flatfile.CreateDataClipRequest} request
     * @param {DataClips.RequestOptions} requestOptions - Request-specific configuration.
     *
     * @throws {@link Flatfile.BadRequestError}
     * @throws {@link Flatfile.NotFoundError}
     *
     * @example
     *     await client.dataClips.create({
     *         name: "name",
     *         sourceSheetId: "sourceSheetId"
     *     })
     */
    create(request: Flatfile.CreateDataClipRequest, requestOptions?: DataClips.RequestOptions): core.HttpResponsePromise<Flatfile.DataClip>;
    private __create;
    /**
     * @param {Flatfile.DataClipId} dataClipId
     * @param {Flatfile.UpdateDataClipRequest} request
     * @param {DataClips.RequestOptions} requestOptions - Request-specific configuration.
     *
     * @example
     *     await client.dataClips.update("dataClipId", {
     *         name: "name"
     *     })
     */
    update(dataClipId: Flatfile.DataClipId, request: Flatfile.UpdateDataClipRequest, requestOptions?: DataClips.RequestOptions): core.HttpResponsePromise<Flatfile.DataClipResponse>;
    private __update;
    /**
     * @param {Flatfile.DataClipId} dataClipId
     * @param {DataClips.RequestOptions} requestOptions - Request-specific configuration.
     *
     * @example
     *     await client.dataClips.delete("dataClipId")
     */
    delete(dataClipId: Flatfile.DataClipId, requestOptions?: DataClips.RequestOptions): core.HttpResponsePromise<Flatfile.Success>;
    private __delete;
    /**
     * @param {Flatfile.DataClipId} dataClipId
     * @param {DataClips.RequestOptions} requestOptions - Request-specific configuration.
     *
     * @example
     *     await client.dataClips.get("dataClipId")
     */
    get(dataClipId: Flatfile.DataClipId, requestOptions?: DataClips.RequestOptions): core.HttpResponsePromise<Flatfile.DataClipResponse>;
    private __get;
    /**
     * Adds records to an existing DataClip.
     *
     * @param {Flatfile.DataClipId} dataClipId
     * @param {Flatfile.AddRecordsToClipRequest} request
     * @param {DataClips.RequestOptions} requestOptions - Request-specific configuration.
     *
     * @throws {@link Flatfile.BadRequestError}
     * @throws {@link Flatfile.NotFoundError}
     *
     * @example
     *     await client.dataClips.addRecordsToClip("dataClipId", {
     *         recordIds: ["recordIds", "recordIds"]
     *     })
     */
    addRecordsToClip(dataClipId: Flatfile.DataClipId, request: Flatfile.AddRecordsToClipRequest, requestOptions?: DataClips.RequestOptions): core.HttpResponsePromise<Flatfile.RecordsResponseData>;
    private __addRecordsToClip;
    /**
     * @param {Flatfile.ListDataClipsRequest} request
     * @param {DataClips.RequestOptions} requestOptions - Request-specific configuration.
     *
     * @throws {@link Flatfile.BadRequestError}
     * @throws {@link Flatfile.NotFoundError}
     *
     * @example
     *     await client.dataClips.list()
     */
    list(request?: Flatfile.ListDataClipsRequest, requestOptions?: DataClips.RequestOptions): core.HttpResponsePromise<Flatfile.ListDataClipResponse>;
    private __list;
    /**
     * @param {Flatfile.DataClipId} dataClipId
     * @param {Flatfile.GetDataClipResolutionsRequest} request
     * @param {DataClips.RequestOptions} requestOptions - Request-specific configuration.
     *
     * @throws {@link Flatfile.BadRequestError}
     * @throws {@link Flatfile.NotFoundError}
     *
     * @example
     *     await client.dataClips.getResolutions("dataClipId")
     */
    getResolutions(dataClipId: Flatfile.DataClipId, request?: Flatfile.GetDataClipResolutionsRequest, requestOptions?: DataClips.RequestOptions): core.HttpResponsePromise<Flatfile.DiffRecordsResponse>;
    private __getResolutions;
    /**
     * @param {Flatfile.DataClipId} dataClipId
     * @param {Flatfile.GetDataClipResolutionIndexRequest} request
     * @param {DataClips.RequestOptions} requestOptions - Request-specific configuration.
     *
     * @throws {@link Flatfile.BadRequestError}
     * @throws {@link Flatfile.NotFoundError}
     *
     * @example
     *     await client.dataClips.getResolutionIndex("dataClipId", {
     *         filterConflicts: "filterConflicts",
     *         id: "id"
     *     })
     */
    getResolutionIndex(dataClipId: Flatfile.DataClipId, request: Flatfile.GetDataClipResolutionIndexRequest, requestOptions?: DataClips.RequestOptions): core.HttpResponsePromise<Flatfile.GetResolutionIndexResponse>;
    private __getResolutionIndex;
    /**
     * @param {Flatfile.DataClipId} dataClipId
     * @param {Flatfile.UpdateResolutionRequest} request
     * @param {DataClips.RequestOptions} requestOptions - Request-specific configuration.
     *
     * @throws {@link Flatfile.BadRequestError}
     * @throws {@link Flatfile.NotFoundError}
     *
     * @example
     *     await client.dataClips.updateResolution("dataClipId", {
     *         resolvedRecords: [{
     *                 recordId: "recordId",
     *                 resolves: [{}, {}]
     *             }, {
     *                 recordId: "recordId",
     *                 resolves: [{}, {}]
     *             }]
     *     })
     */
    updateResolution(dataClipId: Flatfile.DataClipId, request: Flatfile.UpdateResolutionRequest, requestOptions?: DataClips.RequestOptions): core.HttpResponsePromise<Flatfile.Success>;
    private __updateResolution;
    /**
     * @param {Flatfile.DataClipId} dataClipId
     * @param {DataClips.RequestOptions} requestOptions - Request-specific configuration.
     *
     * @throws {@link Flatfile.BadRequestError}
     * @throws {@link Flatfile.NotFoundError}
     *
     * @example
     *     await client.dataClips.refreshResolutions("dataClipId")
     */
    refreshResolutions(dataClipId: Flatfile.DataClipId, requestOptions?: DataClips.RequestOptions): core.HttpResponsePromise<Flatfile.Success>;
    private __refreshResolutions;
    protected _getAuthorizationHeader(): Promise<string | undefined>;
}
